@@ -1,12 +1,14 @@
 import typing
 
+from typing_extensions import TypedDict
+
 
 NetworkId = int
 NetworkName = str
 NetworkReference = typing.Union[NetworkId, NetworkName, None]
 
 
-class NetworkMetadata(typing.TypedDict):
+class NetworkMetadata(TypedDict):
     name: NetworkName
     chain_id: int
     block_explorer: str  # url
